@@ -817,7 +817,7 @@ int ha_myisam::write_row(uchar *buf)
     If we have an auto_increment column and we are writing a changed row
     or a new row, then update the auto_increment value in the record.
   */
-  if (table->next_number_field && buf == table->record[0])
+  if (table && table->next_number_field && buf == table->record[0])
   {
     int error;
     if ((error= update_auto_increment()))
